==> moodle-1.5-mysql.tgz: moodle/lang/sk/appointment.php <==
<?PHP // $Id$ 
      // appointment.php - created with Moodle 1.6 development (2005052400)


$string['allowresubmit'] = 'Povoli optovn odovzdanie zadania';
$string['appointmentdetails'] = 'Detaily zadania';
$string['appointmentlocation'] = 'Umiestnenie zadania';
$string['appointmentname'] = 'Nzov zadania';
$string['date'] = 'Dtum zadania';
$string['description'] = 'Popis';
$string['early'] = '$a skoro';
$string['failedupdatefeedback'] = 'Pokus o aktualizciu odovzdanho zadania od uvatea $a bol nespen ';
$string['feedback'] = 'Odpove na zadanie';
$string['feedbackupdated'] = 'Odpovede na odovzdan zadania boli aktualizovan pre $a ud ';
$string['late'] = '$a neskoro';
$string['maximumgrade'] = 'Maximlna znmka';
$string['maximumsize'] = 'Maximlna vekos';
$string['modulename'] = 'Zadanie';
$string['modulenameplural'] = 'Zadania';
$string['newsubmissions'] = 'Odovzdan zadania';
$string['notgradedyet'] = 'Zadania ete neboli oznmkovan';
$string['notsubmittedyet'] = 'Zadania ete neboli odovzdan';
$string['overwritewarning'] = 'Upozornenie: optovn odovzdanie zadania NAHRAD Vae pvodn zadanie';
$string['saveallfeedback'] = 'Uloi vetky moje odpovede';
$string['submissionfeedback'] = 'Odpove na zadanie';
$string['submissions'] = 'Odovzdan zadania';
$string['submitappointment'] = 'Odovzdajte prosm zadanie prostrednctvom tohto formulra';
$string['submitted'] = 'Zadanie bolo odovzdan';
$string['timeend'] = 'De, do ktorho treba odovzda vypracovan zadanie';
$string['timestart'] = 'De, kedy bola zadan loha na vypracovanie';
$string['typeoffline'] = 'Aktivita offline';
$string['typeuploadsingle'] = 'Prenies jeden sbor';
$string['uploadbadname'] = 'Meno sboru obsahovalo nepovolen znaky. Z tohto dvodu nemohol by sbor prenesen';
$string['uploadedfiles'] = 'prenesen sbory';
$string['uploaderror'] = 'Poas ukladania sboru na server sa vyskytla chyba';
$string['uploadfailnoupdate'] = 'Sbor bol prenesen v poriadku, ale systm nemohol aktualizova Vae odovzdan zadanie!';
$string['uploadfiletoobig'] = 'Prepte, ale sbor je prli vek (limit je $a bytov)';
$string['uploadnofilefound'] = 'Nebol njden iaden sbor - ste si ist, e ste oznaili nejak na prenos?';
$string['uploadnotregistered'] = 'Sbor \'$a\' bol prenesen v poriadku, ale nie je zznam o odovzdan zadania!';
$string['uploadsuccess'] = 'Sbor \'$a\'  bol prenesen spene';
$string['viewfeedback'] = 'Prezrie si znmky za odovzdan zadania a odpove na zadanie';
$string['viewsubmissions'] = 'Prezrie si  $a odovzdanch zadan';
$string['yoursubmission'] = 'Vae zadanie';

?>

==> moodle-1.5.3-mysql.tgz: moodle/lang/sk/appointment.php <==
<?PHP // $Id$ 
      // appointment.php - created with Moodle 1.6 development (2005052400)


$string['allowresubmit'] = 'Povoli optovn odovzdanie zadania';
$string['appointmentdetails'] = 'Detaily zadania';
$string['appointmentlocation'] = 'Umiestnenie zadania';
$string['appointmentname'] = 'Nzov zadania';
$string['date'] = 'Dtum zadania';
$string['description'] = 'Popis';
$string['early'] = '$a skoro';
$string['failedupdatefeedback'] = 'Pokus o aktualizciu odovzdanho zadania od pouvatea $a bol nespen ';
$string['feedback'] = 'Odpove na zadanie';
$string['feedbackupdated'] = 'Odpovede na odovzdan zadania boli aktualizovan pre $a ud ';
$string['late'] = '$a neskoro';
$string['maximumgrade'] = 'Maximlna znmka';
$string['maximumsize'] = 'Maximlna vekos';
$string['modulename'] = 'Zadanie';
$string['modulenameplural'] = 'Zadania';
$string['newsubmissions'] = 'Odovzdan zadania';
$string['notgradedyet'] = 'Zadania ete neboli oznmkovan';
$string['notsubmittedyet'] = 'Zadania ete neboli odovzdan';
$string['overwritewarning'] = 'Upozornenie: optovn odovzdanie zadania NAHRAD Vae pvodn zadanie';
$string['saveallfeedback'] = 'Uloi vetky moje odpovede';
$string['submissionfeedback'] = 'Odpove na zadanie';
$string['submissions'] = 'Odovzdan zadania';
$string['submitappointment'] = 'Odovzdajte prosm zadanie prostrednctvom tohto formulra';
$string['submitted'] = 'Zadanie bolo odovzdan';
$string['timeend'] = 'De, do ktorho treba odovzda vypracovan zadanie';
$string['timestart'] = 'De, kedy bola zadan loha na vypracovanie';
$string['typeoffline'] = 'Aktivita offline';
$string['typeuploadsingle'] = 'Prenies jeden sbor';
$string['uploadbadname'] = 'Meno sboru obsahovalo nepovolen znaky. Z tohto dvodu nemohol by sbor prenesen';
$string['uploadedfiles'] = 'prenesen sbory';
$string['uploaderror'] = 'Poas ukladania sboru na server sa vyskytla chyba';
$string['uploadfailnoupdate'] = 'Sbor bol prenesen v poriadku, ale systm nemohol aktualizova Vae odovzdan zadanie!';
$string['uploadfiletoobig'] = 'Prepte, ale sbor je prli vek (limit je $a bytov)';
$string['uploadnofilefound'] = 'Nebol njden iaden sbor - ste si ist, e ste oznaili nejak na prenos?';
$string['uploadnotregistered'] = 'Sbor \'$a\' bol prenesen v poriadku, ale nie je zznam o odovzdan zadania!';
$string['uploadsuccess'] = 'Sbor \'$a\'  bol prenesen spene';
$string['viewfeedback'] = 'Prezrie si znmky za odovzdan zadania a odpove na zadanie';
$string['viewsubmissions'] = 'Prezrie si  $a odovzdanch zadan';
$string['yoursubmission'] = 'Vae zadanie';

?>
